@@ -74,7 +74,13 @@ const InputFactory::Inputs& InputFactory::GetInputs (const Config& config) throw
 						m_inputs.push_back(new Pop3MailClient(input_name));
 						continue;
 					}
-
+#ifdef USE_ETPAN
+					if (input_type == "imap")
+					{
+						m_inputs.push_back(new ImapMailClient(input_name));
+						continue;
+					}
+#endif
 					if (input_type == "txt")
 					{
 						m_inputs.push_back(new TXTFile(input_name));
