@@ -93,10 +93,12 @@ XMLFile::XMLFile (const string& option_key)
 		StateStack m_state;
 		string m_current_collection;
 		string m_current_collection_type;
+		string m_current_collection_purpose;
+		Database& m_database;
 		Database::CollectionsItems& m_items;
 
 	public:
-		content_handler (SAXParser& parser, Database::CollectionsItems& items);
+		content_handler (SAXParser& parser, Database& database, Database::CollectionsItems& items);
 		virtual void characters (const XMLChar ch[], int start, int length) {}
 		virtual void startDocument () {}
 		virtual void endDocument () {}
@@ -110,11 +112,13 @@ XMLFile::XMLFile (const string& option_key)
 		virtual void skippedEntity (const XMLString& name) {}
 	};
 
-	content_handler::content_handler (SAXParser& parser, Database::CollectionsItems& items)
+	content_handler::content_handler (SAXParser& parser, Database& database, Database::CollectionsItems& items)
 		: m_parser(parser)
 		, m_state()
 		, m_current_collection()
 		, m_current_collection_type()
+		, m_current_collection_purpose()
+		, m_database(database)
 		, m_items(items)
 	{
 		m_state.push(none);
@@ -132,8 +136,12 @@ XMLFile::XMLFile (const string& option_key)
 		static void pdr_start_collection (content_handler& ch, const XMLString& uri, const Attributes& attrList)
 		{
 			ch.m_state.push(content_handler::pdr_collection);
+
 			ch.m_current_collection = attrList.getValue(uri, "name");
 			ch.m_current_collection_type = attrList.getValue(uri, "type");
+			ch.m_current_collection_purpose = attrList.getValue(uri, "purpose");
+
+			ch.m_database.AddCollection(ch.m_current_collection + ',' + ch.m_current_collection_type[0] + ',' + ch.m_current_collection_purpose);
 		}
 
 		static void pdr_collection_start_item (content_handler& ch, const XMLString& uri, const Attributes& attrList)
@@ -233,8 +241,10 @@ XMLFile::XMLFile (const string& option_key)
 		static void pdr_collection_end_collection (content_handler& ch)
 		{
 			end_default(ch);
+
 			ch.m_current_collection.clear();
 			ch.m_current_collection_type.clear();
+			ch.m_current_collection_purpose.clear();
 		}
 
 	void content_handler::endElement (const XMLString& uri, const XMLString& localName, const XMLString& qname)
@@ -283,7 +293,7 @@ void XMLFile::ProcessFile (const Config& config, Database& database, ifstream& i
 			parser.addEncoding(name, &GetEncoding(name));
 		}
 
-		content_handler ch(parser, items);
+		content_handler ch(parser, database, items);
 		parser.setContentHandler(&ch);
 
 		InputSource isrc(ifs);
