@@ -317,7 +317,7 @@ void DiagramCairo::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 	cairo_stroke(m_pContext);
 }
 
-void DiagramCairo::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness, bool continuous, int bar1, int bar2)
+void DiagramCairo::DrawCurve (const Selection& s, RGB color, LineStyle style, double thickness, bool continuous)
 {
 	const size_t* pDimensions = s.shape(); // [0] rows, [1] columns
 
@@ -355,31 +355,6 @@ void DiagramCairo::DrawCurve (const Selection& s, RGB color, LineStyle style, do
 
 		switch (style)
 		{
-			case bars:
-			{
-				if (current)
-				{
-					ptime t(current.m_timestamp);
-					double x = CalcX(t);
-					double y = CalcY(any_cast<double>(current.m_value));
-					double x_width;
-					if (bar1 != 0 && bar2 != 0 && bar1 <= bar2)
-					{
-						x_width = (CalcX(t + m_increment) - x) / double(bar2);
-						x += x_width * double(bar1 - 1);
-					}
-					else
-						x_width = CalcX(t + m_increment) - x;
-					if (x >= m_margin.left)
-					{
-						cairo_rectangle(m_pContext, x, y, x_width, CalcY(m_ymin) - y);
-						cairo_fill(m_pContext);
-						UpdateOrigin(x, CalcY(m_ymin));
-						cairo_stroke(m_pContext);
-					}
-				}
-				break;
-			}
 			case symbol_plus:
 			{
 				if (current)
@@ -518,6 +493,23 @@ void DiagramCairo::SaveAs (const string& filename) const
 		throw Xception(cairo_status_to_string(st));
 }
 
+void DiagramCairo::DrawBar (const ptime& t, double value, int bar1, int bar2, RGB color, bool fix)
+{
+	double x = CalcX(t);
+	double y = CalcY(value);
+	double x_width = (fix) ? (CalcX(t + m_increment) - x) / double(bar2) : (CalcX(min(t + m_increment, m_xmax)) - x) / double(bar2);
+	x += x_width * double(bar1 - 1);
+
+	if (x >= m_margin.left)
+	{
+		cairo_set_source_rgb(m_pContext, RED(color), GREEN(color), BLUE(color));
+		cairo_rectangle(m_pContext, x, y, x_width, CalcY(m_ymin) - y);
+		cairo_fill(m_pContext);
+		UpdateOrigin(x, CalcY(m_ymin));
+		cairo_stroke(m_pContext);
+	}
+}
+
 void DiagramCairo::UpdateOrigin (double x, double y)
 {
 	if (x < m_origin.x)
