@@ -283,6 +283,12 @@ namespace Parser {
 						| str_p("-")								[EXEC(fo_function_name)]
 						| str_p("*")								[EXEC(fo_function_name)]
 						| str_p("/")								[EXEC(fo_function_name)]
+						| str_p("==")								[EXEC(fo_function_name)]
+						| str_p("!=")								[EXEC(fo_function_name)]
+						| str_p("<=")								[EXEC(fo_function_name)]
+						| str_p(">=")								[EXEC(fo_function_name)]
+						| str_p("<")								[EXEC(fo_function_name)]
+						| str_p(">")								[EXEC(fo_function_name)]
 						;
 
 				function	= ch_p('(')
